from setuptools import setup

setup(
    name='cemir-print',
    version='0.1.3',
    description='A colorful printing library for Python',
    author='muslu yüksektepe',
    author_email='musluyuksektepe@gmail.com',
    url='https://github.com/muslu/cemir-print',
    packages=['cemir_print'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)
